NA

Dependencies:   AX12 BMA180_4 L3G4200D_3 mbed

Fork of AX12-HelloWorld by Chris Styles

Revision:
1:b12b06e2fc2d
Parent:
0:f6f8cf11779f
Child:
2:056f36912bf0
--- a/main.cpp	Thu Jun 03 14:25:20 2010 +0000
+++ b/main.cpp	Thu Mar 31 12:03:04 2011 +0000
@@ -4,11 +4,11 @@
 int main() {
 
     AX12 myax12 (p9, p10, 1);
-    
+
     while (1) {
-        myax12.SetGoal(60);  // go to 60 degrees
+        myax12.SetGoal(0);    // go to 0 degrees
         wait (2.0);
-        myax12.SetGoal(240); // go to 240 degrees
+        myax12.SetGoal(300);  // go to 300 degrees
         wait (2.0);
     }
 }
\ No newline at end of file